from django.apps import AppConfig


class TelegramNotifierConfig(AppConfig):
    name = "telegram_notifier"
    default_auto_field = "django.db.models.BigAutoField"
    verbose_name = "Telegram Notifier"
